#!/bin/sh
#
# qhpsi (UN)INSTALL Script ($$N.sh)
# -----------------------------------------------
#
# Purpose:      To install and uninstall the qhpsi patch
#
# Parameters:   -u (uninstall)
#	        VRF (Version to be uninstalled)
#
# Usage:        ./install_qhpsi.sh [-u] [Version]
#
#		Installation: 	./qhpsi.sh
# 		Uninstallation: ./qhpsi.sh -u 014
#
# Return Codes: 0 - Patches applied successfully
#		1 - Original QMAIL files not found (Patch not extracted in QMAIL source directory)
#		2 - Patch files not found 
#
# Output:	qhpsi.log
#
# History:      1.0.1 - Erwin Hoffmann - Initial release
#		1.0.2 -			remove '-v' from cp
#		1.0.3 -			generalized version
#
#---------------------------------------------------------------------------------------
#
DATE=$(date)
LOCDIR=${PWD}
QMAILHOME=$(head -n 1 conf-qmail)
SOLARIS=$(sh ./find-systype.sh | grep -ci "SunOS")
LOGFILE=qhpsi.log
TARGETS=FILES.qhpsi
IFSKEEP=${IFS}
REL=020 # Should be identical to qhpsi level
BUILD=2006220224242


if [ $# -eq 0 ] ; then

	echo "Installing qhpsi $REL (Build $BUILD) at $DATE <<<" | tee -a $LOGFILE 2>&1 
	
	for FILE in $(grep "^= " ${TARGETS} | awk '{print $2}'); do
		echo "Targeting file $FILE ..." | tee -a $LOGFILE 2>&1
		if [ -s ${FILE} ] ; then
			cp ${FILE} ${FILE}.$REL | tee -a $LOGFILE 2>&1
			echo "--> ${FILE} copied to ${FILE}.$REL" | tee -a $LOGFILE 2>&1
		else
			echo "${FILE} not found!"
			exit 1
		fi
		if [ -s ${FILE}.patch ] ; then
			if [ ${SOLARIS} -gt 0 ]; then
				echo "--> Patching qmail source file ${FILE} for Solaris ...." | tee -a $LOGFILE 2>&1
				patch -i ${FILE}.patch ${FILE} 2>&1 | tee -a $LOGFILE
			else
				echo "--> Patching qmail source file ${FILE}  ...." | tee -a $LOGFILE 2>&1
				patch ${FILE} ${FILE}.patch 2>&1 | tee -a $LOGFILE
			fi
		else
			echo "!! ${FILE}.patch not found / not applicable !"
			exit 2
		fi
	done 

	echo "Copying documentation and samples to ${QMAILHOME}/doc/ ..." | tee -a $LOGFILE 2>&1 

	cp [A-Z]*.qhpsi ${QMAILHOME}/doc/ | tee -a $LOGFILE 2>&1
	echo "Installation of qhpsi $REL (Build $BUILD) finished at $DATE <<<" | tee -a $LOGFILE 2>&1 

# Now go for the uninstallation....

elif [ "$1" = "-u" ] ; then

# Get the Version Number from INPUT 

	echo "De-installing qhpsi $REL (Build $BUILD) at $DATE <<<" | tee -a $LOGFILE 2>&1 

	for FILE in $(grep "^= " ${TARGETS} | awk '{print $2}'); do
		echo "Targeting file $FILE ..." | tee -a $LOGFILE 2>&1
		if [ -s ${FILE}.$REL ] ; then
			mv ${FILE}.$REL ${FILE} | tee -a $LOGFILE 2>&1
			touch ${FILE}
			echo "--> ${FILE}.$REL moved to ${FILE}" | tee -a $LOGFILE 2>&1
		else
			echo "!! ${FILE}.$REL not found !"
		fi
	done
	echo "De-installation of qhpsi $REL (Build $BUILD) finished at $DATE <<<" | tee -a $LOGFILE 2>&1 
fi

exit 0
